@@ -239,6 +239,7 @@ void MirrorJob::JobFinished(Job *j)
       stats.error_count++;
    RemoveWaiting(j);
    Delete(j);
+   assert(transfer_count>0);
    transfer_count--;
 }
 
@@ -422,7 +423,10 @@ void  MirrorJob::HandleFile(FileInfo *file)
 	    {
 	       if(S_ISDIR(st.st_mode))
 	       {
-		  chmod(target_name,st.st_mode|0700);
+		  // try to enable write access
+		  // only if not enabled as chmod can clear sgid flags on directories
+		  if(st.st_mode!=(st.st_mode|0700))
+		     chmod(target_name,st.st_mode|0700);
 		  create_target_dir=false;
 	       }
 	       else
@@ -708,6 +712,7 @@ void MirrorJob::HandleChdir(FileAccessRef& session, int &redirections)
       }
       eprintf("mirror: %s\n",session->StrError(res));
       stats.error_count++;
+      assert(transfer_count>=root_transfer_count);
       transfer_count-=root_transfer_count;
       set_state(FINISHING);
       source_session->Close();
@@ -733,6 +738,7 @@ void MirrorJob::HandleListInfoCreation(const FileAccessRef& session,SMTaskRef<Li
    {
       eprintf(_("mirror: protocol `%s' is not suitable for mirror\n"),
 	       session->GetProto());
+      assert(transfer_count>=root_transfer_count);
       transfer_count-=root_transfer_count;
       set_state(FINISHING);
       return;
@@ -761,6 +767,7 @@ void MirrorJob::HandleListInfo(SMTaskRef<ListInfo>& list_info, Ref<FileSet>& set
    {
       eprintf("mirror: %s\n",list_info->ErrorText());
       stats.error_count++;
+      assert(transfer_count>=root_transfer_count);
       transfer_count-=root_transfer_count;
       set_state(FINISHING);
       source_list_info=0;
@@ -786,6 +793,7 @@ int   MirrorJob::Do()
       source_redirections=0;
       source_session->Roll();
       set_state(CHANGING_DIR_SOURCE);
+      remove_this_source_dir=(remove_source_dirs && source_dir.last_char()!='/');
       m=MOVED;
       /*fallthrough*/
    case(CHANGING_DIR_SOURCE):
@@ -810,7 +818,9 @@ int   MirrorJob::Do()
 	 {
 	    if(S_ISDIR(st.st_mode))
 	    {
-	       if(!script_only)
+	       // try to enable write access
+	       // only if not enabled as chmod can clear sgid flags on directories
+	       if(!script_only && (st.st_mode!=(st.st_mode|0700)))
 		  chmod(target_dir,st.st_mode|0700);
 	       create_target_dir=false;
 	       goto pre_CHANGING_DIR_TARGET;
@@ -901,6 +911,7 @@ int   MirrorJob::Do()
       if(source_list_info || target_list_info)
 	 return m;
 
+      assert(transfer_count>=root_transfer_count);
       transfer_count-=root_transfer_count; // leave room for transfers.
 
       if(FlagSet(DEPTH_FIRST) && source_set && !target_set)
@@ -931,6 +942,7 @@ int   MirrorJob::Do()
 	       root_mirror->target_set_recursive=target_set.borrow();
 	 }
 	 root_mirror->stats.dirs++;
+	 transfer_count++; // parent mirror will decrement it.
 	 goto pre_DONE;
       }
 
@@ -1216,9 +1228,9 @@ int   MirrorJob::Do()
 	 break;
 
       // all jobs finished.
-      if(remove_source_dirs && source_dir.last_char()!='/') {
+      if(remove_this_source_dir) {
 	 // remove source directory once.
-	 remove_source_dirs=false;
+	 remove_this_source_dir=false;
 	 if(script)
 	 {
 	    ArgV args("rmdir");
@@ -1359,6 +1371,7 @@ MirrorJob::MirrorJob(MirrorJob *parent,
 
    create_target_dir=true;
    no_target_dir=false;
+   remove_this_source_dir=false;
 
    flags=0;
    max_error_count=0;
@@ -2039,7 +2052,7 @@ CMD(mirror)
 	    }
 	    target_dir=alloca_strdup(target_url.path);
 	 }
-	 if(last_char(arg)=='/' && basename_ptr(arg)[0]!='/')
+	 if(last_char(arg)=='/' && basename_ptr(arg)[0]!='/' && last_char(source_dir)!='/')
 	 {
 	    // user wants source dir name appended.
 	    const char *base=basename_ptr(source_dir);
@@ -2154,7 +2167,8 @@ CMD(mirror)
 CDECL void module_init()
 {
    CmdExec::RegisterCommand("mirror",cmd_mirror,0,
-	 N_("\nMirror specified remote directory to local directory\n\n"
+      N_("\n"
+	 "Mirror specified remote directory to local directory\n\n"
 	 " -c, --continue         continue a mirror job if possible\n"
 	 " -e, --delete           delete files not present at remote site\n"
 	 "     --delete-first     delete old files before transferring new ones\n"
@@ -2179,6 +2193,8 @@ CDECL void module_init()
 	 "\n"
 	 "When using -R, the first directory is local and the second is remote.\n"
 	 "If the second directory is omitted, basename of first directory is used.\n"
-	 "If both directories are omitted, current local and remote directories are used.\n")
+	 "If both directories are omitted, current local and remote directories are used.\n"
+	 "See lftp(1) for a complete list of options.\n"
+      )
    );
 }
