@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1996-2015 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2016 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,6 +101,7 @@ private:
 
    bool create_target_dir;
    bool	no_target_dir;	   // target directory does not exist (for script_only)
+   bool remove_this_source_dir;
 
    SMTaskRef<ListInfo> source_list_info;
    SMTaskRef<ListInfo> target_list_info;
@@ -127,8 +128,11 @@ private:
 
    double transfer_time_elapsed;
    TimeDate transfer_start_ts;
+
+   /* root_transfer_count is the global counter in the root mirror,
+    * and weight of a non-root mirror otherwise. */
    int	 root_transfer_count;
-   int	 &transfer_count;
+   int	 &transfer_count; // reference to root_mirror->root_transfer_count
 
    int	 flags;
    recursion_mode_t recursion_mode;
